@@ -12,7 +12,7 @@ class OrderableAdmin(admin.ModelAdmin):
     """
     jQuery orderable objects in the admin.
 
-    You'll want your object to subclass incuna.db.models.Orderable and you
+    You'll want your object to subclass orderable.models.Orderable and you
     want to add sort_order_display to list_display.
     """
     list_display = ('__str__', 'sort_order_display')
@@ -40,11 +40,7 @@ class OrderableAdmin(admin.ModelAdmin):
 
     def get_url_name(self):
         meta = self.model._meta
-        try:
-            model_name = meta.model_name
-        except AttributeError:
-            # model_name is called module_name in django < 1.6
-            model_name = meta.module_name
+        model_name = meta.model_name
 
         return '{0}admin_{1}_{2}_reorder'.format(
             self.admin_site.name, meta.app_label, model_name,
@@ -68,6 +64,12 @@ class OrderableAdmin(admin.ModelAdmin):
 
         return HttpResponse("OK")
 
+    class Media:
+        js = (
+            '//ajax.googleapis.com/ajax/libs/jquery/1.11.2/jquery.min.js',
+            '//ajax.googleapis.com/ajax/libs/jqueryui/1.11.2/jquery-ui.min.js',
+        )
+
 
 class OrderableTabularInline(admin.TabularInline):
     """
@@ -76,3 +78,9 @@ class OrderableTabularInline(admin.TabularInline):
     You'll want your object to subclass incuna.db.models.Orderable.
     """
     template = "admin/edit_inline/orderable_tabular.html"
+
+    class Media:
+        js = (
+            '//ajax.googleapis.com/ajax/libs/jquery/1.11.2/jquery.min.js',
+            '//ajax.googleapis.com/ajax/libs/jqueryui/1.11.2/jquery-ui.min.js',
+        )
